@@ -8,7 +8,10 @@ class ModelWithCachedFields(object):
 
     def _flag_FIELD_as_stale(self, field=None, and_recalculate=None, commit=True):
         if and_recalculate is None:
-            and_recalculate = settings.EAGER_RECALCULATION
+            try:
+                and_recalculate = settings.CACHED_FIELD_EAGER_RECALCULATION
+            except AttributeError:
+                and_recalculate = True
         if not getattr(self, field.recalculation_needed_field_name):
             setattr(self, field.recalculation_needed_field_name, True)
             kwargs = {field.recalculation_needed_field_name: True}
@@ -68,10 +71,6 @@ class CachedFieldMixin(object):
       `cached_field_name' to specify a field name other than cached_FIELD
       `recalculation_needed_field_name' to specify a field name other than
         FIELD_recalculation_needed
-    Caveats:
-      * recalculate_ uses .update(cached_FIELD= to set the value
-      * flag_as_stale uses .update, as well
-      * recalculation task will not adapt to recalculation_needed_field_name option
     """
 
     def __init__(self, *args, **kwargs):
